+ Developer Guide Overview
QuantaStor was designed from the ground up so that you can develop your own applications to remotely manage your storage systems.
Supported Languages
You can use just about any programming language you like to communicate with QuantaStor via our RESTful API. Recommended tools:
- C/C++ - libcurl [1]
- Python - PyCurl [2]
- Unix/Linux/VMware/XenServer scripting - curl [3]
- PHP curl - [4]
Examples
Here's are some examples of how to enumerate various objects using the RESTful API and the curl utility:
curl -U admin:password https://192.168.0.116:8153/qstorapi/hostEnum -k curl -U admin:password https://192.168.0.116:8153/qstorapi/storageVolumeEnum -k curl -U admin:password https://192.168.0.116:8153/qstorapi/storageSystemGet -k curl -U admin:password https://192.168.0.116:8153/qstorapi/storagePoolEnum -k curl -U admin:password https://192.168.0.116:8153/qstorapi/userEnum -k curl -U admin:password https://192.168.0.116:8153/qstorapi/networkShareEnum -k
One quick way to test is to just enter one of these URLs (https://192.168.0.116:8153/qstorapi/hostEnum) into your web browser which will work as long as your system admin account is still using the default password. Pretty much every known language has a curl type library/module for it so the above technique will work everywhere, you just need to get up to speed with your preferred language's curl API mechanism.
Note you can even access APIs using wget which in this example will store the results into a file called hostEnum:
wget --no-check-certificate https://192.168.0.135:8153/qstorapi/hostEnum
Reflection
The RESTful API has basic support for reflection, meaning that you can learn about all the arguments for a given API just by calling it with the 'help' parameter like so:
curl -k -U admin:password https://192.168.0.116:8153/qstorapi/hostAdd?help
Calling APIs with Parameters
To call an API with parameters you'll need to add a & between each parameter you specify and a ? between the API name and the start of the parameters like so:
curl -k -U admin:password "https://192.168.0.116:8153/qstorapi/hostAdd?iqn=iqn.1991-05.com.microsoft:osn-mediaserver3&hostname=mediaserver3&flags=0"
Which will return JSON output like this (note the quotes so that the ampersand is not interpreted by the shell):
{
"task":{
"i18nDescription":{
"messageText":null,
"messageId":null
},
"operation":"add",
"id":"ca54a531-6386-a4f7-b9de-30f505329bb1",
"objectType":"Host",
"finishTimeStamp":"1969-12-31 16:00:00",
"isRemote":false,
"createdTimeStamp":"2012-08-23 21:53:40",
"state":0,
"acls":[
{
"reserved":0,
"objectId":"ca54a531-6386-a4f7-b9de-30f505329bb1",
"ownerType":23,
"ownerId":"252d4786-b19f-ae43-1ff6-453bee8a652e",
"accessLevel":2,
"objectType":16
}
],
"clientIpAddress":"127.0.0.1",
"parentId":null,
"modifiedByUserId":null,
"progress":0,
"customId":null,
"type":16,
"description":"Adding host 'mediaserver3' to service with iSCSI initiator IQN 'iqn.1991-05.com.microsoft:osn-mediaserver3'.",
"errorMessage":{
"function":null,
"severity":0,
"errorCode":0,
"file":null,
"message":{
"messageText":null,
"messageId":null
},
"line":0
},
"modifiedTimeStamp":"1969-12-31 16:00:00",
"storageSystemId":"50ce62e6-6846-c5b3-d8a1-27061a696604",
"createdByUserId":"252d4786-b19f-ae43-1ff6-453bee8a652e",
"name":"Add Host",
"startTimeStamp":"2012-08-23 21:53:40",
"taskState":2
},
"obj":{
"username":null,
"storageSystemId":"50ce62e6-6846-c5b3-d8a1-27061a696604",
"isRemote":false,
"hostGroupId":null,
"name":"mediaserver3",
"ipAddress":null,
"createdByUserId":"252d4786-b19f-ae43-1ff6-453bee8a652e",
"modifiedTimeStamp":"1969-12-31 16:00:00",
"createdTimeStamp":"2012-08-23 21:53:40",
"state":0,
"hostOsType":0,
"initiatorPortList":[
{
"storageSystemId":"50ce62e6-6846-c5b3-d8a1-27061a696604",
"isRemote":false,
"hostId":"4fb8c2da-235a-18f9-2620-1d8aa5da89c5",
"name":"iqn.1991-05.com.microsoft:osn-mediaserver3",
"ipAddress":null,
"createdByUserId":"252d4786-b19f-ae43-1ff6-453bee8a652e",
"modifiedTimeStamp":"1969-12-31 16:00:00",
"createdTimeStamp":"2012-08-23 21:53:40",
"wwpn":null,
"state":0,
"iqn":"iqn.1991-05.com.microsoft:osn-mediaserver3",
"initiatorType":0,
"modifiedByUserId":null,
"customId":null,
"type":13,
"id":"535abed2-830a-a437-d6fd-5af7c5b5c263"
}
],
"modifiedByUserId":null,
"customId":null,
"password":"********",
"type":11,
"id":"4fb8c2da-235a-18f9-2620-1d8aa5da89c5",
"description":"None"
}
}
Async vs. Sync (blocking vs non-blocking) API calls
All of the APIs for QuantaStor that modify the configuration in any way will start a task in the system. If you call any API with the flags parameter set to 0 it'll be treated as a blocking call which wait for the task to complete before returning. If you want to call the function and have it return immediately you can pass a 1 as the flags parameter which indicates to the server that the caller wants this to be an asynchronous non-blocking call. With asynchronous calls you'll get the task object back so that you can use the taskGet API to monitor the progress of the operation. When the task completes it will populate the customId property of the task to contain the ID(s) of the objects which were created/deleted/modified by the task.
Task Monitoring
As indicated above, sometimes you'll want to call an API asynchronously so that you can monitor the progress of the task and/or because you want to queue up multiple operations to run simultaneously. In such cases where you call an API asynchronously (flags=1) you can monitor the progress of the task using the tastGet API or the tastEnum API if you want to see all running tasks. When the task is completed you can check the customId property to see the ID(s) of the objects created/modified.
Security
QuantaStor REST interface always uses SSL via HTTPS. You can change the pem keys on your system by replacing the qstorapi_server.pem file located in /opt/osnexus/quantastor/restsrv/. If you want to use plain HTTP without SSL you can rename or remove the qstorapi_server.pem and the RESTful service will automatically fall back to using HTTP. After removing the file just restart the RESTful service interface with:
service restsrv restart
If you want to block access to the restful interface you can stop the service and/or you can remove access to port 8153 by removing the entry associated with that port number from the /etc/init.d/iptables configuration file and then restart iptables like so:
service iptables restart
In a similar manner you can block access to the web management interface on port 80/8080.
Supported SOAP / WebServices Implementations
- gSOAP (C++, all platforms)
- Apache Axis (Java, all platforms)
- .NET (C# & Visual Basic, Windows)
API List
The following represents the full API list for every API in QuantaStor. Nothing is left out, if you can do it from the web management interface or the CLI, it's here.
aclAdd API
Example
Argument List
objectId: <xs:string>
ownerType: <xs:unsignedInt>
flags: <xs:unsignedInt>
ownerId: <xs:string>
accessLevel: <xs:unsignedInt>
objectType: <xs:unsignedInt>
aclModify API
Example
Argument List
objectId: <xs:string>
ownerType: <xs:unsignedInt>
flags: <xs:unsignedInt>
ownerId: <xs:string>
accessLevel: <xs:unsignedInt>
objectType: <xs:unsignedInt>
aclRemove API
Example
Argument List
ownerId: <xs:string>
ownerType: <xs:unsignedInt>
flags: <xs:unsignedInt>
objectId: <xs:string>
objectType: <xs:unsignedInt>
alertClear API
Example
Argument List
flags: <xs:unsignedInt>
id: <xs:string>
alertClearAll API
Example
Argument List
flags: <xs:unsignedInt>
alertConfigGet API
Example
Argument List
flags: <xs:unsignedInt>
alertConfigSet API
Example
Argument List
smtpServerIpAddress: <xs:string>
smtpPassword: <xs:string>
poolFreeSpaceCriticalAlertThreshold: <xs:unsignedInt>
poolFreeSpaceAlertThreshold: <xs:unsignedInt>
poolFreeSpaceWarningThreshold: <xs:unsignedInt>
senderEmailAddress: <xs:string>
customerSupportEmailAddress: <xs:string>
flags: <xs:unsignedInt>
pagerDutyServiceKey: <xs:string>
smtpUsername: <xs:string>
smtpAuthType: <xs:unsignedInt>
alertEnum API
Example
Argument List
flags: <xs:unsignedInt>
alertGet API
Example
Argument List
flags: <xs:unsignedInt>
id: <xs:string>
alertRaise API
Example
Argument List
message: <xs:string>
flags: <xs:unsignedInt>
severity: <xs:unsignedInt>
auditLogClear API
Example
Argument List
flags: <xs:unsignedInt>
auditLogDisable API
Example
Argument List
flags: <xs:unsignedInt>
auditLogEnable API
Example
Argument List
flags: <xs:unsignedInt>
auditLogGet API
Example
Argument List
startDate: <xs:dateTime>
endDate: <xs:dateTime>
user: <xs:string>
flags: <xs:unsignedInt>
cloudBackupScheduleAssocEnum API
Example
Argument List
flags: <xs:unsignedInt>
schedule: <xs:string>
cloudBackupScheduleAssocGet API
Example
Argument List
scheduleId: <xs:string>
storageVolumeId: <xs:string>
cloudBackupScheduleCreate API
Example
Argument List
storageVolumeList: <xs:string[]>
setEnabled: <xs:unsignedInt>
name: <xs:string>
startDate: <xs:dateTime>
hoursOfDay: <xs:unsignedInt>
daysOfWeek: <xs:unsignedInt>
maxBackups: <xs:unsignedInt>
priority: <xs:unsignedInt>
cloudContainerId: <xs:string>
flags: <xs:unsignedInt>
description: <xs:string>
cloudBackupScheduleDelete API
Example
Argument List
flags: <xs:unsignedInt>
schedule: <xs:string>
cloudBackupScheduleDisable API
Example
Argument List
flags: <xs:unsignedInt>
schedule: <xs:string>
cloudBackupScheduleEnable API
Example
Argument List
flags: <xs:unsignedInt>
schedule: <xs:string>
cloudBackupScheduleEnum API
Example
Argument List
flags: <xs:unsignedInt>
cloudBackupScheduleGet API
Example
Argument List
flags: <xs:unsignedInt>
schedule: <xs:string>
cloudBackupScheduleModify API
Example
Argument List
setEnabled: <xs:unsignedInt>
description: <xs:string>
startDate: <xs:dateTime>
hoursOfDay: <xs:unsignedInt>
schedule: <xs:string>
daysOfWeek: <xs:unsignedInt>
maxBackups: <xs:unsignedInt>
cloudContainerId: <xs:string>
flags: <xs:unsignedInt>
name: <xs:string>
cloudBackupScheduleVolumeAddRemove API
Example
Argument List
storageVolumeList: <xs:string[]>
modType: <xs:unsignedInt>
flags: <xs:unsignedInt>
schedule: <xs:string>
cloudContainerAdd API
Example
Argument List
storageUrl: <xs:string>
flags: <xs:unsignedInt>
enableNfs: <xs:boolean>
credentialsId: <xs:string>
locationId: <xs:string>
encryptionKey: <xs:string>
cloudContainerCreate API
Example
Argument List
name: <xs:string>
storageUrl: <xs:string>
flags: <xs:unsignedInt>
locationId: <xs:string>
enableNfs: <xs:boolean>
credentialsId: <xs:string>
encryptionKey: <xs:string>
description: <xs:string>
cloudContainerDelete API
Example
Argument List
flags: <xs:unsignedInt>
container: <xs:string>
cloudContainerDisable API
Example
Argument List
flags: <xs:unsignedInt>
container: <xs:string>
cloudContainerEnable API
Example
Argument List
flags: <xs:unsignedInt>
container: <xs:string>
cloudContainerEnum API
Example
Argument List
flags: <xs:unsignedInt>
cloudContainerGet API
Example
Argument List
flags: <xs:unsignedInt>
container: <xs:string>
cloudContainerModify API
Example
Argument List
container: <xs:string>
name: <xs:string>
flags: <xs:unsignedInt>
enableNfs: <xs:boolean>
encryptionKey: <xs:string>
description: <xs:string>
cloudContainerRemove API
Example
Argument List
flags: <xs:unsignedInt>
container: <xs:string>
cloudContainerRepair API
Example
Argument List
flags: <xs:unsignedInt>
container: <xs:string>
cloudProviderCredentialsAdd API
Example
Argument List
username: <xs:string>
machine: <xs:string>
providerId: <xs:string>
password: <xs:string>
flags: <xs:unsignedInt>
cloudProviderCredentialsEnum API
Example
Argument List
flags: <xs:unsignedInt>
cloudProviderCredentialsGet API
Example
Argument List
credentialId: <xs:string>
flags: <xs:unsignedInt>
cloudProviderCredentialsRemove API
Example
Argument List
flags: <xs:unsignedInt>
credentialsId: <xs:string>
cloudProviderEnum API
Example
Argument List
flags: <xs:unsignedInt>
cloudProviderGet API
Example
Argument List
providerId: <xs:string>
flags: <xs:unsignedInt>
cloudProviderLocationAdd API
Example
Argument List
flags: <xs:unsignedInt>
providerId: <xs:string>
locationTag: <xs:string>
cloudProviderLocationEnum API
Example
Argument List
flags: <xs:unsignedInt>
cloudProviderLocationGet API
Example
Argument List
flags: <xs:unsignedInt>
locationId: <xs:string>
cloudProviderLocationRemove API
Example
Argument List
flags: <xs:unsignedInt>
locationId: <xs:string>
clusterFailoverGroupActivate API
Example
Argument List
storageSystemId: <xs:string>
flags: <xs:unsignedInt>
clusterFailoverGroup: <xs:string>
clusterFailoverGroupCreate API
Example
Argument List
storageSystemCluster: <xs:string>
name: <xs:string>
zoneConfig: <xs:string>
flags: <xs:unsignedInt>
storagePool: <xs:string>
description: <xs:string>
clusterFailoverGroupDelete API
Example
Argument List
flags: <xs:unsignedInt>
clusterFailoverGroup: <xs:string>
clusterFailoverGroupEnum API
Example
Argument List
flags: <xs:unsignedInt>
clusterFailoverGroupGet API
Example
Argument List
flags: <xs:unsignedInt>
clusterFailoverGroup: <xs:string>
clusterFailoverGroupModify API
Example
Argument List
description: <xs:string>
zoneConfig: <xs:string>
flags: <xs:unsignedInt>
clusterFailoverGroup: <xs:string>
storagePool: <xs:string>
name: <xs:string>
customApi API
Example
Argument List
flags: <xs:unsignedInt>
params: <ns0:keyValuePair[]>
method: <xs:string>
echo API
Example
Argument List
inputMessage: <xs:string>
eventEnum API
Example
Argument List
maxEvents: <xs:unsignedInt>
serviceTimeStamp: <xs:dateTime>
startingIndex: <xs:unsignedInt>
eventListenerNotify API
Example
Argument List
storageSystemId: <xs:string>
list: <ns0:event[]>
eventListenerRegister API
Example
Argument List
eventListenerObj: <ns0:eventListener>
eventListenerUnregister API
Example
Argument List
listenerId: <xs:string>
fcTargetPortDisable API
Example
Argument List
flags: <xs:unsignedInt>
port: <xs:string>
fcTargetPortEnable API
Example
Argument List
flags: <xs:unsignedInt>
port: <xs:string>
fcTargetPortEnum API
Example
Argument List
flags: <xs:unsignedInt>
fcTargetPortGet API
Example
Argument List
flags: <xs:unsignedInt>
port: <xs:string>
getHardwareConfig API
Example
Argument List
flags: <xs:unsignedInt>
getLocalizedMessage API
Example
Argument List
locale: <xs:string>
flags: <xs:unsignedInt>
i18nStr: <ns0:i18nString>
getSecurityConfig API
Example
Argument List
storageSystemId: <xs:string>
flags: <xs:unsignedInt>
getSystemConfig API
Example
Argument List
storageSystemId: <xs:string>
flags: <xs:unsignedInt>
hostAdd API
Example
Argument List
username: <xs:string>
description: <xs:string>
hostname: <xs:string>
hostType: <xs:unsignedInt>
iqn: <xs:string>
flags: <xs:unsignedInt>
password: <xs:string>
ipAddress: <xs:string>
hostEnum API
Example
Argument List
flags: <xs:unsignedInt>
hostGet API
Example
Argument List
host: <xs:string>
flags: <xs:unsignedInt>
hostGroupCreate API
Example
Argument List
hostList: <xs:string[]>
flags: <xs:unsignedInt>
name: <xs:string>
description: <xs:string>
hostGroupDelete API
Example
Argument List
host: <xs:string>
flags: <xs:unsignedInt>
deleteAssociatedHosts: <xs:boolean>
hostGroupEnum API
Example
Argument List
flags: <xs:unsignedInt>
hostGroupGet API
Example
Argument List
flags: <xs:unsignedInt>
hostGroup: <xs:string>
hostGroupHostAddRemove API
Example
Argument List
hostList: <xs:string[]>
modType: <xs:unsignedInt>
flags: <xs:unsignedInt>
hostGroup: <xs:string>
hostGroupModify API
Example
Argument List
newName: <xs:string>
flags: <xs:unsignedInt>
newDescription: <xs:string>
hostGroup: <xs:string>
hostInitiatorAdd API
Example
Argument List
host: <xs:string>
iqn: <xs:string>
flags: <xs:unsignedInt>
hostInitiatorEnum API
Example
Argument List
host: <xs:string>
flags: <xs:unsignedInt>
hostInitiatorGet API
Example
Argument List
initiator: <xs:string>
flags: <xs:unsignedInt>
hostInitiatorRemove API
Example
Argument List
host: <xs:string>
iqn: <xs:string>
flags: <xs:unsignedInt>
hostModify API
Example
Argument List
newIpAddress: <xs:string>
newUsername: <xs:string>
newPassword: <xs:string>
newHostType: <xs:unsignedInt>
host: <xs:string>
flags: <xs:unsignedInt>
newDescription: <xs:string>
hostRemove API
Example
Argument List
host: <xs:string>
flags: <xs:unsignedInt>
hwAlarmEnum API
Example
Argument List
flags: <xs:unsignedInt>
hwController: <xs:string>
hwAlarmGet API
Example
Argument List
hwAlarm: <xs:string>
flags: <xs:unsignedInt>
hwBatteryBackupUnitEnum API
Example
Argument List
flags: <xs:unsignedInt>
hwController: <xs:string>
hwBatteryBackupUnitGet API
Example
Argument List
hwBatteryBackupUnit: <xs:string>
flags: <xs:unsignedInt>
hwControllerClearAlarms API
Example
Argument List
controllerId: <xs:string>
flags: <xs:unsignedInt>
hwControllerEnum API
Example
Argument List
hwControllerGroup: <xs:string>
flags: <xs:unsignedInt>
hwControllerGet API
Example
Argument List
flags: <xs:unsignedInt>
hwController: <xs:string>
hwControllerGroupEnum API
Example
Argument List
flags: <xs:unsignedInt>
hwControllerGroupGet API
Example
Argument List
hwControllerGroup: <xs:string>
flags: <xs:unsignedInt>
hwControllerImportForeignUnits API
Example
Argument List
controllerId: <xs:string>
flags: <xs:unsignedInt>
hwControllerRescan API
Example
Argument List
controllerId: <xs:string>
flags: <xs:unsignedInt>
hwControllerRescanAll API
Example
Argument List
storageSystemId: <xs:string>
flags: <xs:unsignedInt>
hwControllerSilenceAlarms API
Example
Argument List
controllerId: <xs:string>
flags: <xs:unsignedInt>
hwDiskEnum API
Example
Argument List
flags: <xs:unsignedInt>
hwController: <xs:string>
hwDiskGet API
Example
Argument List
hwDisk: <xs:string>
flags: <xs:unsignedInt>
hwDiskIdentify API
Example
Argument List
flags: <xs:unsignedInt>
durationInSeconds: <xs:unsignedInt>
diskId: <xs:string>
hwDiskMarkHotSpare API
Example
Argument List
clearMark: <xs:boolean>
flags: <xs:unsignedInt>
diskId: <xs:string>
hwDiskRemove API
Example
Argument List
flags: <xs:unsignedInt>
diskId: <xs:string>
hwEnclosureEnum API
Example
Argument List
flags: <xs:unsignedInt>
hwController: <xs:string>
hwEnclosureGet API
Example
Argument List
hwEnclosure: <xs:string>
flags: <xs:unsignedInt>
hwLogicalDriveEnum API
Example
Argument List
hwUnit: <xs:string>
flags: <xs:unsignedInt>
hwLogicalDriveGet API
Example
Argument List
hwLogicalDrive: <xs:string>
flags: <xs:unsignedInt>
hwSwitchAdapterEnum API
Example
Argument List
flags: <xs:unsignedInt>
hwSwitchAdapterGet API
Example
Argument List
flags: <xs:unsignedInt>
switchAdapterId: <xs:string>
hwSwitchCredentialsAdd API
Example
Argument List
username: <xs:string>
domainPassword: <xs:string>
primaryStorageSystem: <xs:string>
secondaryStorageSystem: <xs:string>
switchAdapterId: <xs:string>
switchType: <xs:unsignedInt>
managementProtocol: <xs:unsignedInt>
flags: <xs:unsignedInt>
password: <xs:string>
ipAddress: <xs:string>
hwSwitchCredentialsEnum API
Example
Argument List
flags: <xs:unsignedInt>
switchAdapterId: <xs:string>
hwSwitchCredentialsGet API
Example
Argument List
flags: <xs:unsignedInt>
switchCredentials: <xs:string>
hwSwitchCredentialsModify API
Example
Argument List
domainPassword: <xs:string>
flags: <xs:unsignedInt>
primaryStorageSystem: <xs:string>
credentialsId: <xs:string>
secondaryStorageSystem: <xs:string>
password: <xs:string>
hwSwitchCredentialsRemove API
Example
Argument List
credsId: <xs:string>
flags: <xs:unsignedInt>
hwSwitchEnum API
Example
Argument List
flags: <xs:unsignedInt>
switchAdapterId: <xs:string>
hwSwitchFailoverGroupActivate API
Example
Argument List
storageSystemId: <xs:string>
hwSwitchFailoverGroup: <xs:string>
flags: <xs:unsignedInt>
hwSwitchFailoverGroupCreate API
Example
Argument List
primaryStorageSystemId: <xs:string>
name: <xs:string>
secondaryStorageSystemId: <xs:string>
virtualHostSubnet: <xs:string>
storagePoolList: <xs:string[]>
secondaryZonesetId: <xs:string>
virtualHostIpAddress: <xs:string>
virtualHostGateway: <xs:string>
flags: <xs:unsignedInt>
primaryZonesetId: <xs:string>
description: <xs:string>
hwSwitchFailoverGroupDelete API
Example
Argument List
hwSwitchFailoverGroup: <xs:string>
flags: <xs:unsignedInt>
hwSwitchFailoverGroupEnum API
Example
Argument List
flags: <xs:unsignedInt>
hwSwitchFailoverGroupGet API
Example
Argument List
hwSwitchFailoverGroupId: <xs:string>
flags: <xs:unsignedInt>
hwSwitchFailoverGroupModify API
Example
Argument List
primaryStorageSystemId: <xs:string>
name: <xs:string>
primaryZonesetId: <xs:string>
secondaryStorageSystemId: <xs:string>
virtualHostSubnet: <xs:string>
storagePoolList: <xs:string[]>
secondaryZonesetId: <xs:string>
virtualHostIpAddress: <xs:string>
virtualHostGateway: <xs:string>
flags: <xs:unsignedInt>
hwSwitchFailoverGroup: <xs:string>
description: <xs:string>
hwSwitchFailoverGroupPoolAssocEnum API
Example
Argument List
hwSwitchFailoverGroup: <xs:string>
flags: <xs:unsignedInt>
hwSwitchFailoverGroupPoolAssocGet API
Example
Argument List
hwSwitchFailoverGroupId: <xs:string>
storagePoolId: <xs:string>
flags: <xs:unsignedInt>
hwSwitchFailoverGroupSetMode API
Example
Argument List
hwSwitchFailoverGroup: <xs:string>
flags: <xs:unsignedInt>
failoverMode: <xs:unsignedInt>
hwSwitchFailoverGroupSystemAssocAdd API
Example
Argument List
storageSystemId: <xs:string>
zonesetId: <xs:string>
hwSwitchFailoverGroup: <xs:string>
flags: <xs:unsignedInt>
hwSwitchFailoverGroupSystemAssocEnum API
Example
Argument List
hwSwitchFailoverGroup: <xs:string>
flags: <xs:unsignedInt>
hwSwitchFailoverGroupSystemAssocGet API
Example
Argument List
storageSystemId: <xs:string>
hwSwitchFailoverGroupId: <xs:string>
flags: <xs:unsignedInt>
hwSwitchFailoverGroupSystemAssocRemove API
Example
Argument List
storageSystemId: <xs:string>
hwSwitchFailoverGroup: <xs:string>
flags: <xs:unsignedInt>
hwSwitchGet API
Example
Argument List
switchId: <xs:string>
flags: <xs:unsignedInt>
hwSwitchRescan API
Example
Argument List
switchId: <xs:string>
flags: <xs:unsignedInt>
hwSwitchZonesetActivate API
Example
Argument List
zonesetId: <xs:string>
flags: <xs:unsignedInt>
switchCredentialsId: <xs:string>
hwSwitchZonesetEnum API
Example
Argument List
flags: <xs:unsignedInt>
switchCredentialsId: <xs:string>
hwSwitchZonesetGet API
Example
Argument List
switchZoneset: <xs:string>
flags: <xs:unsignedInt>
hwUnitCreate API
Example
Argument List
raidType: <xs:unsignedInt>
diskList: <xs:string[]>
controllerId: <xs:string>
flags: <xs:unsignedInt>
hwUnitDelete API
Example
Argument List
flags: <xs:unsignedInt>
unitId: <xs:string>
hwUnitEnum API
Example
Argument List
flags: <xs:unsignedInt>
hwController: <xs:string>
hwUnitGet API
Example
Argument List
hwUnit: <xs:string>
flags: <xs:unsignedInt>
hwUnitGrow API
Example
Argument List
diskList: <xs:string[]>
flags: <xs:unsignedInt>
stripeSizeKb: <xs:unsignedInt>
initPriority: <xs:unsignedInt>
unitId: <xs:string>
hwUnitIdentify API
Example
Argument List
flags: <xs:unsignedInt>
durationInSeconds: <xs:unsignedInt>
unitId: <xs:string>
hwUnitSsdCacheCreate API
Example
Argument List
raidType: <xs:unsignedInt>
ssdDiskList: <xs:string[]>
controllerId: <xs:string>
flags: <xs:unsignedInt>
hwUnitSsdCacheDisable API
Example
Argument List
flags: <xs:unsignedInt>
unitId: <xs:string>
hwUnitSsdCacheEnable API
Example
Argument List
unitSsdCacheId: <xs:string>
flags: <xs:unsignedInt>
unitId: <xs:string>
ibTargetPortEnum API
Example
Argument List
flags: <xs:unsignedInt>
ibTargetPortGet API
Example
Argument List
flags: <xs:unsignedInt>
port: <xs:string>
libratoMetricsConfigGet API
Example
Argument List
flags: <xs:unsignedInt>
storageSystem: <xs:string>
libratoMetricsConfigSet API
Example
Argument List
username: <xs:string>
enableAlertAnnotations: <xs:boolean>
storageSystem: <xs:string>
postIntervalSec: <xs:unsignedInt>
token: <xs:string>
enableConfigAnnotations: <xs:boolean>
autoDashboardCreate: <xs:boolean>
flags: <xs:unsignedInt>
licenseActivate API
Example
Argument List
activationKey: <xs:string>
flags: <xs:unsignedInt>
licenseActivateOnline API
Example
Argument List
flags: <xs:unsignedInt>
licenseKey: <xs:string>
licenseAdd API
Example
Argument List
keyBlock: <xs:string>
flags: <xs:unsignedInt>
storageSystem: <xs:string>
licenseEnum API
Example
Argument List
flags: <xs:unsignedInt>
licenseGet API
Example
Argument List
flags: <xs:unsignedInt>
license: <xs:string>
licenseRemove API
Example
Argument List
flags: <xs:unsignedInt>
license: <xs:string>
login API
Example
Argument List
reserved: <xs:string>
Example
Argument List
secure: <xs:boolean>
subtreeCheck: <xs:boolean>
clientFilter: <xs:string>
readOnly: <xs:boolean>
flags: <xs:unsignedInt>
networkShareId: <xs:string>
customOptions: <xs:string>
async: <xs:boolean>
Example
Argument List
networkShare: <xs:string>
flags: <xs:unsignedInt>
Example
Argument List
flags: <xs:unsignedInt>
networkShareClientId: <xs:string>
networkShareId: <xs:string>
Example
Argument List
secure: <xs:boolean>
subtreeCheck: <xs:boolean>
networkShareClientId: <xs:string>
readOnly: <xs:boolean>
flags: <xs:unsignedInt>
networkShareId: <xs:string>
customOptions: <xs:string>
async: <xs:boolean>
Example
Argument List
flags: <xs:unsignedInt>
networkShareClientId: <xs:string>
networkShareId: <xs:string>
Example
Argument List
description: <xs:string>
readOnly: <xs:boolean>
networkShare: <xs:string>
flags: <xs:unsignedInt>
cloneName: <xs:string>
provisionableId: <xs:string>
isActive: <xs:boolean>
Example
Argument List
name: <xs:string>
isPublic: <xs:boolean>
flags: <xs:unsignedInt>
provisionableId: <xs:string>
isActive: <xs:boolean>
description: <xs:string>
Example
Argument List
flags: <xs:unsignedInt>
networkShareId: <xs:string>
Example
Argument List
networkShare: <xs:string>
flags: <xs:unsignedInt>
Example
Argument List
networkShare: <xs:string>
flags: <xs:unsignedInt>
Example
Argument List
flags: <xs:unsignedInt>
Example
Argument List
networkShare: <xs:string>
flags: <xs:unsignedInt>
Example
Argument List
networkShare: <xs:string>
flags: <xs:unsignedInt>
name: <xs:string>
isActive: <xs:boolean>
description: <xs:string>
Example
Argument List
nfsMode: <xs:unsignedInt>
reserved: <xs:string>
enableKerberos: <xs:boolean>
storageSystem: <xs:string>
defaultOptions: <xs:string>
flags: <xs:unsignedInt>
Example
Argument List
snapshotShare: <xs:string>
networkShare: <xs:string>
flags: <xs:unsignedInt>
Example
Argument List
flags: <xs:unsignedInt>
storageSystem: <xs:string>
Example
Argument List
description: <xs:string>
snapshotName: <xs:string>
readOnly: <xs:boolean>
networkShare: <xs:string>
flags: <xs:unsignedInt>
provisionableId: <xs:string>
isActive: <xs:boolean>
objectEnum API
Example
Argument List
propValue: <xs:string>
flags: <xs:unsignedInt>
propType: <xs:unsignedInt>
propKey: <xs:string>
objectGet API
Example
Argument List
flags: <xs:unsignedInt>
id: <xs:string>
objectLock API
Example
Argument List
id: <xs:string>
objectPropertyGet API
Example
Argument List
flags: <xs:unsignedInt>
objectId: <xs:string>
propKey: <xs:string>
objectPropertySet API
Example
Argument List
propType: <xs:unsignedInt>
propValue: <xs:string>
flags: <xs:unsignedInt>
objectId: <xs:string>
propKey: <xs:string>
objectUnlock API
Example
Argument List
id: <xs:string>
permissionDefinitionEnum API
Example
Argument List
flags: <xs:unsignedInt>
physicalDiskEnum API
Example
Argument List
flags: <xs:unsignedInt>
physicalDiskList: <xs:string[]>
physicalDiskGet API
Example
Argument List
physicalDrive: <xs:string>
flags: <xs:unsignedInt>
physicalDiskIdentify API
Example
Argument List
physicalDrive: <xs:string>
pattern: <xs:string>
duration: <xs:unsignedInt>
flags: <xs:unsignedInt>
physicalDiskPathAssocEnum API
Example
Argument List
flags: <xs:unsignedInt>
multipathDiskId: <xs:string>
physicalDiskPathAssocGet API
Example
Argument List
flags: <xs:unsignedInt>
multipathDiskId: <xs:string>
physicalDiskId: <xs:string>
physicalDiskScan API
Example
Argument List
storageSystemId: <xs:string>
flags: <xs:unsignedInt>
registerSecurityToken API
Example
Argument List
flags: <xs:unsignedInt>
token: <xs:string>
signedToken: <xs:string>
remoteStoragePoolEnum API
Example
Argument List
remoteStorageSystemId: <xs:string>
flags: <xs:unsignedInt>
replicaAssocDelete API
Example
Argument List
deleteReplicaAssocHead: <xs:boolean>
flags: <xs:unsignedInt>
assocId: <xs:string>
deleteSourceReplicatable: <xs:boolean>
deleteTargetReplicatable: <xs:boolean>
replicaAssocEnum API
Example
Argument List
replicatableId: <xs:string>
targetsOnly: <xs:boolean>
flags: <xs:unsignedInt>
sourcesOnly: <xs:boolean>
replicaAssocGet API
Example
Argument List
flags: <xs:unsignedInt>
assocId: <xs:string>
replicaAssocUpdate API
Example
Argument List
assocObj: <ns0:replicaAssoc>
flags: <xs:unsignedInt>
replicaCreate API
Example
Argument List
replicaDescription: <xs:string>
reserved: <xs:string>
replicationPriority: <xs:unsignedInt>
targetStoragePoolId: <xs:string>
forcePrimary: <xs:boolean>
replicatableId: <xs:string>
smartSync: <xs:boolean>
flags: <xs:unsignedInt>
replicaName: <xs:string>
storageSystemLinkId: <xs:string>
Example
Argument List
replicaDescription: <xs:string>
sourceShare: <ns0:networkShare>
reserved: <xs:string>
replicationPriority: <xs:unsignedInt>
sourceShareParent: <ns0:networkShare>
targetStoragePoolId: <xs:string>
forcePrimary: <xs:boolean>
smartSync: <xs:boolean>
flags: <xs:unsignedInt>
replicaName: <xs:string>
replicaCreateVolumeTarget API
Example
Argument List
replicaDescription: <xs:string>
reserved: <xs:string>
replicationPriority: <xs:unsignedInt>
targetStoragePoolId: <xs:string>
forcePrimary: <xs:boolean>
smartSync: <xs:boolean>
flags: <xs:unsignedInt>
replicaName: <xs:string>
sourceVolumeParent: <ns0:storageVolume>
sourceVolume: <ns0:storageVolume>
replicaStop API
Example
Argument List
flags: <xs:unsignedInt>
assocId: <xs:string>
replicaSync API
Example
Argument List
flags: <xs:unsignedInt>
assocId: <xs:string>
replicationScheduleAddRemove API
Example
Argument List
storageVolumeList: <xs:string[]>
networkShareList: <xs:string[]>
modType: <xs:unsignedInt>
flags: <xs:unsignedInt>
schedule: <xs:string>
replicationScheduleAssocEnum API
Example
Argument List
flags: <xs:unsignedInt>
schedule: <xs:string>
replicationScheduleAssocGet API
Example
Argument List
replicatableId: <xs:string>
scheduleId: <xs:string>
replicationScheduleCreate API
Example
Argument List
storageVolumeList: <xs:string[]>
setEnabled: <xs:unsignedInt>
name: <xs:string>
targetProvisionableId: <xs:string>
startDate: <xs:dateTime>
targetStorageCloudId: <xs:string>
storageCloudId: <xs:string>
daysOfWeek: <xs:unsignedInt>
priority: <xs:unsignedInt>
networkShareList: <xs:string[]>
flags: <xs:unsignedInt>
storageSystemLinkId: <xs:string>
hoursOfDay: <xs:unsignedInt>
maxReplicas: <xs:unsignedInt>
description: <xs:string>
replicationScheduleDelete API
Example
Argument List
flags: <xs:unsignedInt>
schedule: <xs:string>
replicationScheduleDisable API
Example
Argument List
flags: <xs:unsignedInt>
schedule: <xs:string>
replicationScheduleEnable API
Example
Argument List
flags: <xs:unsignedInt>
schedule: <xs:string>
replicationScheduleEnum API
Example
Argument List
flags: <xs:unsignedInt>
replicationScheduleGet API
Example
Argument List
flags: <xs:unsignedInt>
schedule: <xs:string>
replicationScheduleModify API
Example
Argument List
setEnabled: <xs:unsignedInt>
description: <xs:string>
startDate: <xs:dateTime>
hoursOfDay: <xs:unsignedInt>
storageCloudId: <xs:string>
daysOfWeek: <xs:unsignedInt>
schedule: <xs:string>
flags: <xs:unsignedInt>
maxReplicas: <xs:unsignedInt>
name: <xs:string>
roleCreate API
Example
Argument List
flags: <xs:unsignedInt>
permissionList: <ns0:permissionAssignment[]>
inheritsFrom: <xs:string>
name: <xs:string>
description: <xs:string>
roleDelete API
Example
Argument List
flags: <xs:unsignedInt>
role: <xs:string>
roleEnum API
Example
Argument List
flags: <xs:unsignedInt>
roleGet API
Example
Argument List
flags: <xs:unsignedInt>
role: <xs:string>
roleModify API
Example
Argument List
newName: <xs:string>
flags: <xs:unsignedInt>
role: <xs:string>
newDescription: <xs:string>
rolePermissionAssignmentEnum API
Example
Argument List
roleId: <xs:string>
flags: <xs:unsignedInt>
rolePermissionAssignmentGet API
Example
Argument List
flags: <xs:unsignedInt>
operation: <xs:string>
role: <xs:string>
objectType: <xs:string>
rolePermissionsAddRemove API
Example
Argument List
flags: <xs:unsignedInt>
modType: <xs:unsignedInt>
role: <xs:string>
permissionList: <ns0:permissionAssignment[]>
roleSubjectAssocEnum API
Example
Argument List
flags: <xs:unsignedInt>
role: <xs:string>
roleSubjectAssocGet API
Example
Argument List
flags: <xs:unsignedInt>
role: <xs:string>
subject: <xs:string>
sessionClose API
Example
Argument List
sessionId: <xs:string>
flags: <xs:unsignedInt>
sessionEnum API
Example
Argument List
flags: <xs:unsignedInt>
host: <xs:string>
storageVolume: <xs:string>
sessionGet API
Example
Argument List
sessionId: <xs:string>
flags: <xs:unsignedInt>
siteAssocEnum API
Example
Argument List
flags: <xs:unsignedInt>
siteAssocGet API
Example
Argument List
storageSystemId: <xs:string>
flags: <xs:unsignedInt>
siteId: <xs:string>
siteCreate API
Example
Argument List
storageSystemList: <xs:string[]>
location: <xs:string>
flags: <xs:unsignedInt>
name: <xs:string>
description: <xs:string>
siteDelete API
Example
Argument List
flags: <xs:unsignedInt>
site: <xs:string>
siteEnum API
Example
Argument List
flags: <xs:unsignedInt>
siteGet API
Example
Argument List
flags: <xs:unsignedInt>
site: <xs:string>
siteModify API
Example
Argument List
flags: <xs:unsignedInt>
location: <xs:string>
siteId: <xs:string>
name: <xs:string>
description: <xs:string>
siteStorageSystemAddRemove API
Example
Argument List
storageSystemList: <xs:string[]>
modType: <xs:unsignedInt>
flags: <xs:unsignedInt>
site: <xs:string>
snapshotScheduleAssocEnum API
Example
Argument List
flags: <xs:unsignedInt>
schedule: <xs:string>
snapshotScheduleAssocGet API
Example
Argument List
scheduleId: <xs:string>
storageVolumeId: <xs:string>
snapshotScheduleCreate API
Example
Argument List
storageVolumeList: <xs:string[]>
setEnabled: <xs:unsignedInt>
name: <xs:string>
startDate: <xs:dateTime>
hoursOfDay: <xs:unsignedInt>
storageCloudId: <xs:string>
daysOfWeek: <xs:unsignedInt>
networkShareList: <xs:string[]>
flags: <xs:unsignedInt>
maxSnapshots: <xs:unsignedInt>
description: <xs:string>
snapshotScheduleDelete API
Example
Argument List
flags: <xs:unsignedInt>
schedule: <xs:string>
snapshotScheduleDisable API
Example
Argument List
flags: <xs:unsignedInt>
schedule: <xs:string>
snapshotScheduleEnable API
Example
Argument List
flags: <xs:unsignedInt>
schedule: <xs:string>
snapshotScheduleEnum API
Example
Argument List
flags: <xs:unsignedInt>
snapshotScheduleGet API
Example
Argument List
flags: <xs:unsignedInt>
schedule: <xs:string>
snapshotScheduleModify API
Example
Argument List
setEnabled: <xs:unsignedInt>
description: <xs:string>
startDate: <xs:dateTime>
hoursOfDay: <xs:unsignedInt>
storageCloudId: <xs:string>
daysOfWeek: <xs:unsignedInt>
schedule: <xs:string>
flags: <xs:unsignedInt>
maxSnapshots: <xs:unsignedInt>
name: <xs:string>
snapshotScheduleVolumeAddRemove API
Example
Argument List
storageVolumeList: <xs:string[]>
networkShareList: <xs:string[]>
modType: <xs:unsignedInt>
flags: <xs:unsignedInt>
schedule: <xs:string>
storageCloudCreate API
Example
Argument List
defaultChapPassword: <xs:string>
tier: <xs:string>
name: <xs:string>
parentStorageCloudId: <xs:string>
userList: <ns0:storageCloudSubjectAssoc[]>
flags: <xs:unsignedInt>
resourceList: <ns0:storageCloudResourceAssoc[]>
organization: <xs:string>
defaultChapUsername: <xs:string>
description: <xs:string>
storageCloudDelete API
Example
Argument List
storageCloud: <xs:string>
flags: <xs:unsignedInt>
storageCloudEnum API
Example
Argument List
flags: <xs:unsignedInt>
storageCloudGet API
Example
Argument List
storageCloud: <xs:string>
flags: <xs:unsignedInt>
storageCloudModify API
Example
Argument List
defaultChapPassword: <xs:string>
name: <xs:string>
parentStorageCloudId: <xs:string>
flags: <xs:unsignedInt>
tier: <xs:string>
organization: <xs:string>
storageCloud: <xs:string>
defaultChapUsername: <xs:string>
description: <xs:string>
storageCloudResourceAddRemove API
Example
Argument List
resourceList: <ns0:storageCloudResourceAssoc[]>
storageCloud: <xs:string>
modType: <xs:unsignedInt>
flags: <xs:unsignedInt>
storageCloudResourceAssocEnum API
Example
Argument List
flags: <xs:unsignedInt>
resource: <xs:string>
storageCloudResourceAssocGet API
Example
Argument List
flags: <xs:unsignedInt>
storageCloud: <xs:string>
resource: <xs:string>
storageCloudResourceSetMode API
Example
Argument List
flags: <xs:unsignedInt>
storageCloud: <xs:string>
resource: <ns0:storageCloudResourceAssoc>
storageCloudSubjectAssocEnum API
Example
Argument List
flags: <xs:unsignedInt>
subject: <xs:string>
storageCloudSubjectAssocGet API
Example
Argument List
storageCloud: <xs:string>
flags: <xs:unsignedInt>
subject: <xs:string>
storageCloudUserAddRemove API
Example
Argument List
userList: <ns0:storageCloudSubjectAssoc[]>
storageCloud: <xs:string>
modType: <xs:unsignedInt>
flags: <xs:unsignedInt>
storagePoolCreate API
Example
Argument List
profile: <xs:string>
physicalDiskList: <xs:string[]>
name: <xs:string>
raidType: <xs:unsignedInt>
poolType: <xs:unsignedInt>
enableCompression: <xs:boolean>
noBarriers: <xs:boolean>
enableSsd: <xs:boolean>
flags: <xs:unsignedInt>
isDefault: <xs:boolean>
description: <xs:string>
storagePoolDestroy API
Example
Argument List
flags: <xs:unsignedInt>
storagePool: <xs:string>
storagePoolDeviceEnum API
Example
Argument List
storagePoolId: <xs:string>
flags: <xs:unsignedInt>
storagePoolDeviceGet API
Example
Argument List
flags: <xs:unsignedInt>
storagePoolDevice: <xs:string>
storagePoolEnum API
Example
Argument List
flags: <xs:unsignedInt>
storagePoolExpand API
Example
Argument List
flags: <xs:unsignedInt>
storagePool: <xs:string>
storagePoolExport API
Example
Argument List
flags: <xs:unsignedInt>
storagePool: <xs:string>
storagePoolGet API
Example
Argument List
flags: <xs:unsignedInt>
storagePool: <xs:string>
storagePoolGrow API
Example
Argument List
raidType: <xs:unsignedInt>
flags: <xs:unsignedInt>
physicalDiskList: <xs:string[]>
storagePool: <xs:string>
storagePoolIdentify API
Example
Argument List
duration: <xs:unsignedInt>
pattern: <xs:string>
flags: <xs:unsignedInt>
storagePool: <xs:string>
storagePoolModify API
Example
Argument List
profile: <xs:string>
newName: <xs:string>
enableCompression: <xs:boolean>
isDefault: <xs:boolean>
storagePool: <xs:string>
noBarriers: <xs:boolean>
enableSsd: <xs:boolean>
flags: <xs:unsignedInt>
newDescription: <xs:string>
storagePoolProfileEnum API
Example
Argument List
flags: <xs:unsignedInt>
storagePoolProfileGet API
Example
Argument List
storagePoolProfile: <xs:string>
flags: <xs:unsignedInt>
storagePoolReplicationConfigCreate API
Example
Argument List
primaryStoragePoolId: <xs:string>
diskBarrier: <xs:boolean>
protocolType: <xs:string>
replicationPort: <xs:unsignedInt>
secondaryStoragePoolId: <xs:string>
flags: <xs:unsignedInt>
resyncRate: <xs:unsignedLong>
diskFlushes: <xs:boolean>
storageSystemLinkId: <xs:string>
storagePoolReplicationConfigDelete API
Example
Argument List
scrubMetadataDevice: <xs:boolean>
flags: <xs:unsignedInt>
storagePoolReplicationConfigId: <xs:string>
storagePoolReplicationConfigEnum API
Example
Argument List
flags: <xs:unsignedInt>
storagePoolReplicationConfigGet API
Example
Argument List
storagePoolReplicationConfig: <xs:string>
flags: <xs:unsignedInt>
storagePoolReplicationConfigModify API
Example
Argument List
diskBarrier: <xs:boolean>
protocolType: <xs:string>
replicationPort: <xs:unsignedInt>
flags: <xs:unsignedInt>
resyncRate: <xs:unsignedLong>
diskFlushes: <xs:boolean>
storageSystemLinkId: <xs:string>
storagePoolReplicationConfigId: <xs:string>
storagePoolRescan API
Example
Argument List
flags: <xs:unsignedInt>
storageSystem: <xs:string>
options: <xs:string>
storagePoolSpareAddRemove API
Example
Argument List
flags: <xs:unsignedInt>
modType: <xs:unsignedInt>
physicalDiskList: <xs:string[]>
storagePool: <xs:string>
storagePoolStart API
Example
Argument List
flags: <xs:unsignedInt>
storagePool: <xs:string>
storagePoolStop API
Example
Argument List
flags: <xs:unsignedInt>
storagePool: <xs:string>
storagePoolUpdateRedirect API
Example
Argument List
flags: <xs:unsignedInt>
storagePool: <xs:string>
storageQuotaCreate API
Example
Argument List
utilizableSpace: <xs:unsignedLong>
name: <xs:string>
maxVolumes: <xs:unsignedInt>
storageCloudId: <xs:string>
policyFlags: <xs:unsignedInt>
provisionableSize: <xs:unsignedLong>
storagePoolId: <xs:string>
flags: <xs:unsignedInt>
maxShares: <xs:unsignedInt>
description: <xs:string>
storageQuotaDelete API
Example
Argument List
storageQuota: <xs:string>
flags: <xs:unsignedInt>
storageQuotaEnum API
Example
Argument List
flags: <xs:unsignedInt>
storageQuotaGet API
Example
Argument List
storageQuota: <xs:string>
flags: <xs:unsignedInt>
storageQuotaModify API
Example
Argument List
utilizableSpace: <xs:unsignedLong>
name: <xs:string>
maxVolumes: <xs:unsignedInt>
storageCloudId: <xs:string>
policyFlags: <xs:unsignedInt>
provisionableSize: <xs:unsignedLong>
storageQuota: <xs:string>
flags: <xs:unsignedInt>
maxShares: <xs:unsignedInt>
description: <xs:string>
Example
Argument List
storageQuota: <xs:string>
modType: <xs:unsignedInt>
storageShareList: <xs:string[]>
flags: <xs:unsignedInt>
Example
Argument List
networkShare: <xs:string>
flags: <xs:unsignedInt>
Example
Argument List
storageQuotaId: <xs:string>
shareId: <xs:string>
storageQuotaVolumeAddRemove API
Example
Argument List
storageVolumeList: <xs:string[]>
storageQuota: <xs:string>
modType: <xs:unsignedInt>
flags: <xs:unsignedInt>
storageQuotaVolumeAssocEnum API
Example
Argument List
flags: <xs:unsignedInt>
storageVolume: <xs:string>
storageQuotaVolumeAssocGet API
Example
Argument List
storageQuotaId: <xs:string>
storageVolumeId: <xs:string>
storageSystemClusterAssocEnum API
Example
Argument List
flags: <xs:unsignedInt>
storageSystemClusterAssocGet API
Example
Argument List
storageSystemId: <xs:string>
storageSystemClusterId: <xs:string>
flags: <xs:unsignedInt>
storageSystemClusterCreate API
Example
Argument List
targetPort: <xs:string>
name: <xs:string>
virtualHostIpAddress: <xs:string>
virtualHostGateway: <xs:string>
flags: <xs:unsignedInt>
virtualHostSubnetMask: <xs:string>
virtualHostName: <xs:string>
description: <xs:string>
storageSystemClusterDelete API
Example
Argument List
flags: <xs:unsignedInt>
storageSystemClusterEnum API
Example
Argument List
flags: <xs:unsignedInt>
storageSystemClusterGet API
Example
Argument List
storageSystemCluster: <xs:string>
flags: <xs:unsignedInt>
storageSystemClusterModify API
Example
Argument List
targetPort: <xs:string>
name: <xs:string>
virtualHostIpAddress: <xs:string>
virtualHostGateway: <xs:string>
flags: <xs:unsignedInt>
virtualHostSubnetMask: <xs:string>
virtualHostName: <xs:string>
description: <xs:string>
storageSystemClusterNodeAdd API
Example
Argument List
nodeAdminUsername: <xs:string>
flags: <xs:unsignedInt>
nodeIpAddress: <xs:string>
nodeAdminPassword: <xs:string>
storageSystemClusterNodeEject API
Example
Argument List
storageSystemClusterObj: <ns0:storageSystemCluster>
flags: <xs:unsignedInt>
storageSystemClusterNodeJoin API
Example
Argument List
flags: <xs:unsignedInt>
storageSystemClusterObj: <ns0:storageSystemCluster>
masterNode: <ns0:storageSystem>
storageSystemClusterNodeRemove API
Example
Argument List
storageSystemId: <xs:string>
flags: <xs:unsignedInt>
storageSystemClusterNodeSetMaster API
Example
Argument List
storageSystemId: <xs:string>
flags: <xs:unsignedInt>
storageSystemClusterNodeSync API
Example
Argument List
flags: <xs:unsignedInt>
storageSystemClusterObj: <ns0:storageSystemCluster>
masterNode: <ns0:storageSystem>
storageSystemEnum API
Example
Argument List
flags: <xs:unsignedInt>
storageSystemGet API
Example
Argument List
flags: <xs:unsignedInt>
storageSystem: <xs:string>
storageSystemGroupAddRemoveLinks API
Example
Argument List
linkIdList: <xs:string[]>
modType: <xs:unsignedInt>
flags: <xs:unsignedInt>
groupId: <xs:string>
storageSystemGroupAssocEnum API
Example
Argument List
flags: <xs:unsignedInt>
storageSystemGroupAssocGet API
Example
Argument List
linkId: <xs:string>
flags: <xs:unsignedInt>
groupId: <xs:string>
storageSystemGroupCreate API
Example
Argument List
groupPassword: <xs:string>
flags: <xs:unsignedInt>
name: <xs:string>
virtualIpAddress: <xs:string>
description: <xs:string>
storageSystemGroupDelete API
Example
Argument List
deleteAssociatedLinks: <xs:boolean>
flags: <xs:unsignedInt>
groupId: <xs:string>
storageSystemGroupEnum API
Example
Argument List
flags: <xs:unsignedInt>
storageSystemGroupGet API
Example
Argument List
flags: <xs:unsignedInt>
groupId: <xs:string>
storageSystemGroupModify API
Example
Argument List
description: <xs:string>
flags: <xs:unsignedInt>
groupId: <xs:string>
virtualIpAddress: <xs:string>
name: <xs:string>
storageSystemGroupSetPassword API
Example
Argument List
groupPassword: <xs:string>
flags: <xs:unsignedInt>
groupId: <xs:string>
storageSystemLinkCreate API
Example
Argument List
linkType: <xs:unsignedInt>
localIpAddress: <xs:string>
description: <xs:string>
remoteAdminPassword: <xs:string>
storageSystemId: <xs:string>
flags: <xs:unsignedInt>
remoteIpAddress: <xs:string>
remoteAdminUser: <xs:string>
bandwidthLimit: <xs:unsignedInt>
storageSystemLinkDelete API
Example
Argument List
linkId: <xs:string>
flags: <xs:unsignedInt>
storageSystemLinkDisconnect API
Example
Argument List
remoteStorageSystemId: <xs:string>
flags: <xs:unsignedInt>
storageSystemLinkEnum API
Example
Argument List
flags: <xs:unsignedInt>
storageSystemLinkEstablish API
Example
Argument List
linkObj: <ns0:storageSystemLink>
flags: <xs:unsignedInt>
storageSystemLinkGet API
Example
Argument List
linkId: <xs:string>
flags: <xs:unsignedInt>
storageSystemLinkModify API
Example
Argument List
linkType: <xs:unsignedInt>
description: <xs:string>
linkId: <xs:string>
localIpAddress: <xs:string>
flags: <xs:unsignedInt>
remoteIpAddress: <xs:string>
bandwidthLimit: <xs:unsignedInt>
storageSystemLinkRefresh API
Example
Argument List
linkId: <xs:string>
flags: <xs:unsignedInt>
storageSystemLinkSetCredentials API
Example
Argument List
linkId: <xs:string>
remoteAdminPassword: <xs:string>
flags: <xs:unsignedInt>
remoteAdminUser: <xs:string>
storageSystemLinkVerify API
Example
Argument List
linkObj: <ns0:storageSystemLink>
flags: <xs:unsignedInt>
storageSystemModify API
Example
Argument List
searchSuffix: <xs:string>
newName: <xs:string>
newLocation: <xs:string>
storageSystem: <xs:string>
newDnsServerList: <xs:string[]>
arpFilterMode: <xs:unsignedInt>
bondMode: <xs:unsignedInt>
domainSuffix: <xs:string>
flags: <xs:unsignedInt>
newDescription: <xs:string>
storageSystemRecover API
Example
Argument List
recoveryPoint: <xs:string>
recoverNetworkConfig: <xs:boolean>
flags: <xs:unsignedInt>
storageSystem: <xs:string>
storageSystemRecoveryPointEnum API
Example
Argument List
flags: <xs:unsignedInt>
storageSystem: <xs:string>
storageSystemRestart API
Example
Argument List
flags: <xs:unsignedInt>
storageSystem: <xs:string>
storageSystemSendLogs API
Example
Argument List
storageSystemId: <xs:string>
flags: <xs:unsignedInt>
storageSystemShutdown API
Example
Argument List
flags: <xs:unsignedInt>
storageSystem: <xs:string>
storageSystemUpdateCheck API
Example
Argument List
flags: <xs:unsignedInt>
storageSystem: <xs:string>
storageSystemUpgrade API
Example
Argument List
upgradeTarget: <xs:boolean>
upgradeService: <xs:boolean>
storageSystem: <xs:string>
upgradeWebServer: <xs:boolean>
flags: <xs:unsignedInt>
upgradeManager: <xs:boolean>
storageVolumeAclAddRemove API
Example
Argument List
flags: <xs:unsignedInt>
hostList: <xs:string[]>
modType: <xs:unsignedInt>
storageVolume: <xs:string>
storageVolumeAclAddRemoveEx API
Example
Argument List
storageVolumeList: <xs:string[]>
host: <xs:string>
modType: <xs:unsignedInt>
flags: <xs:unsignedInt>
storageVolumeAclEnum API
Example
Argument List
flags: <xs:unsignedInt>
host: <xs:string>
storageVolume: <xs:string>
storageVolumeAclGet API
Example
Argument List
flags: <xs:unsignedInt>
host: <xs:string>
storageVolume: <xs:string>
storageVolumeClone API
Example
Argument List
storageVolume: <xs:string>
description: <xs:string>
accessMode: <xs:unsignedInt>
cloneName: <xs:string>
flags: <xs:unsignedInt>
provisionableId: <xs:string>
storageVolumeCloudBackupCreate API
Example
Argument List
reserved: <xs:string>
sourceVolumeId: <xs:string>
priority: <xs:unsignedInt>
backupVolumeName: <xs:string>
cloudContainerId: <xs:string>
flags: <xs:unsignedInt>
backupVolumeDescription: <xs:string>
storageVolumeCloudBackupRestore API
Example
Argument List
reserved: <xs:string>
recoveredVolumeName: <xs:string>
sourceVolumeId: <xs:string>
priority: <xs:unsignedInt>
storagePoolId: <xs:string>
flags: <xs:unsignedInt>
recoveredVolumeDescription: <xs:string>
storageVolumeCreate API
Example
Argument List
chapPolicy: <xs:unsignedInt>
count: <xs:unsignedInt>
name: <xs:string>
accessMode: <xs:unsignedInt>
description: <xs:string>
flags: <xs:unsignedInt>
thinProvisioned: <xs:boolean>
chapPassword: <xs:string>
provisionableId: <xs:string>
chapUsername: <xs:string>
size: <xs:unsignedLong>
storageVolumeCreateEx API
Example
Argument List
count: <xs:unsignedInt>
name: <xs:string>
accessMode: <xs:unsignedInt>
description: <xs:string>
flags: <xs:unsignedInt>
percentReserved: <xs:unsignedInt>
chapPolicy: <xs:unsignedInt>
chapPassword: <xs:string>
provisionableId: <xs:string>
chapUsername: <xs:string>
size: <xs:unsignedLong>
storageVolumeDelete API
Example
Argument List
storageVolumeList: <xs:string[]>
flags: <xs:unsignedInt>
recursivelyDeleteSnapshots: <xs:boolean>
storageVolumeEnum API
Example
Argument List
storageVolumeList: <xs:string[]>
flags: <xs:unsignedInt>
storageVolumeGet API
Example
Argument List
flags: <xs:unsignedInt>
storageVolume: <xs:string>
storageVolumeGroupAssocEnum API
Example
Argument List
flags: <xs:unsignedInt>
storageVolume: <xs:string>
storageVolumeGroupAssocGet API
Example
Argument List
storageVolumeGroupId: <xs:string>
storageVolumeId: <xs:string>
storageVolumeGroupClone API
Example
Argument List
storageVolumeGroup: <xs:string>
description: <xs:string>
accessMode: <xs:unsignedInt>
flags: <xs:unsignedInt>
cloneNamePrefix: <xs:string>
provisionableId: <xs:string>
storageVolumeGroupCreate API
Example
Argument List
storageVolumeList: <xs:string[]>
flags: <xs:unsignedInt>
name: <xs:string>
description: <xs:string>
storageVolumeGroupDelete API
Example
Argument List
flags: <xs:unsignedInt>
storageVolumeGroup: <xs:string>
deleteAssociatedVolumes: <xs:boolean>
storageVolumeGroupEnum API
Example
Argument List
flags: <xs:unsignedInt>
storageVolumeGroupGet API
Example
Argument List
flags: <xs:unsignedInt>
storageVolumeGroup: <xs:string>
storageVolumeGroupModify API
Example
Argument List
newName: <xs:string>
flags: <xs:unsignedInt>
storageVolumeGroup: <xs:string>
newDescription: <xs:string>
storageVolumeGroupSnapshot API
Example
Argument List
count: <xs:unsignedInt>
storageVolumeGroup: <xs:string>
description: <xs:string>
accessMode: <xs:unsignedInt>
snapshotNamePrefix: <xs:string>
flags: <xs:unsignedInt>
provisionableId: <xs:string>
storageVolumeGroupVolumeAddRemove API
Example
Argument List
storageVolumeList: <xs:string[]>
flags: <xs:unsignedInt>
modType: <xs:unsignedInt>
storageVolumeGroup: <xs:string>
storageVolumeModify API
Example
Argument List
storageVolume: <xs:string>
newName: <xs:string>
flags: <xs:unsignedInt>
newAccessMode: <xs:unsignedInt>
chapUsername: <xs:string>
chapPolicy: <xs:unsignedInt>
chapPassword: <xs:string>
clearSnapshotFlag: <xs:boolean>
newDescription: <xs:string>
storageVolumeResize API
Example
Argument List
flags: <xs:unsignedInt>
newSizeInBytes: <xs:unsignedLong>
storageVolume: <xs:string>
provisionableId: <xs:string>
storageVolumeRestore API
Example
Argument List
snapshotVolume: <xs:string>
storageVolume: <xs:string>
flags: <xs:unsignedInt>
storageVolumeSnapshot API
Example
Argument List
count: <xs:unsignedInt>
storageVolume: <xs:string>
description: <xs:string>
accessMode: <xs:unsignedInt>
flags: <xs:unsignedInt>
snapshotName: <xs:string>
provisionableId: <xs:string>
storageVolumeUtilizationEnum API
Example
Argument List
flags: <xs:unsignedInt>
storageVolume: <xs:string>
storageVolumeUtilizationGet API
Example
Argument List
flags: <xs:unsignedInt>
utilizationId: <xs:string>
storageVolumeUtilizationGetRetentionPeriod API
Example
Argument List
flags: <xs:unsignedInt>
storageVolumeUtilizationSetRetentionPeriod API
Example
Argument List
flags: <xs:unsignedInt>
daysToRetain: <xs:unsignedInt>
targetPortDisable API
Example
Argument List
flags: <xs:unsignedInt>
port: <xs:string>
targetPortEnable API
Example
Argument List
flags: <xs:unsignedInt>
port: <xs:string>
targetPortEnum API
Example
Argument List
flags: <xs:unsignedInt>
targetPortGet API
Example
Argument List
flags: <xs:unsignedInt>
port: <xs:string>
targetPortModify API
Example
Argument List
description: <xs:string>
iscsiEnabled: <xs:boolean>
mtu: <xs:unsignedInt>
configType: <xs:string>
netmask: <xs:string>
vportFloatList: <xs:string[]>
gateway: <xs:string>
flags: <xs:unsignedInt>
ipAddress: <xs:string>
port: <xs:string>
targetPortRescan API
Example
Argument List
flags: <xs:unsignedInt>
storageSystem: <xs:string>
targetPortRestart API
Example
Argument List
flags: <xs:unsignedInt>
port: <xs:string>
targetVirtualInterfaceCreate API
Example
Argument List
macAddress: <xs:string>
description: <xs:string>
portList: <xs:string[]>
parentPortId: <xs:string>
mtu: <xs:unsignedInt>
storageSystemId: <xs:string>
netmask: <xs:string>
flags: <xs:unsignedInt>
ipAddress: <xs:string>
gateway: <xs:string>
targetVirtualInterfaceMove API
Example
Argument List
targetPortId: <xs:string>
flags: <xs:unsignedInt>
virtualInterfaceId: <xs:string>
targetVirtualPortCreate API
Example
Argument List
macAddress: <xs:string>
description: <xs:string>
portList: <xs:string[]>
mtu: <xs:unsignedInt>
storageSystemId: <xs:string>
netmask: <xs:string>
flags: <xs:unsignedInt>
ipAddress: <xs:string>
gateway: <xs:string>
targetVirtualPortDelete API
Example
Argument List
flags: <xs:unsignedInt>
port: <xs:string>
taskCancel API
Example
Argument List
flags: <xs:unsignedInt>
id: <xs:string>
taskClearAll API
Example
Argument List
flags: <xs:unsignedInt>
taskEnum API
Example
Argument List
taskIdlist: <xs:string[]>
flags: <xs:unsignedInt>
taskGet API
Example
Argument List
flags: <xs:unsignedInt>
id: <xs:string>
userAdd API
Adds a new user to the system. User accounts can access QuantaStor via the web management interface, remote scripting and via the qstorapi RESTful API.
Example
curl -U username:password -k https://hostname:8153/userAdd?username=tiger&password=passWORD1&firstName=Tiger&lastName=Woods&role=Administrator
Argument List
username: <xs:string> defaultChapPassword: <xs:string> alertSubscriptions: <xs:unsignedInt> description: <xs:string> firstName: <xs:string> lastName: <xs:string> flags: <xs:unsignedInt> emailAddress: <xs:string> role: <xs:string> password: <xs:string> defaultChapUsername: <xs:string>
userEnum API
Example
Argument List
flags: <xs:unsignedInt>
userGet API
Example
Argument List
flags: <xs:unsignedInt>
user: <xs:string>
userGroupAssocEnum API
Example
Argument List
flags: <xs:unsignedInt>
user: <xs:string>
userGroupAssocGet API
Example
Argument List
userId: <xs:string>
userGroupId: <xs:string>
userGroupCreate API
Example
Argument List
userList: <xs:string[]>
flags: <xs:unsignedInt>
name: <xs:string>
description: <xs:string>
userGroupDelete API
Example
Argument List
flags: <xs:unsignedInt>
userGroup: <xs:string>
userGroupEnum API
Example
Argument List
flags: <xs:unsignedInt>
userGroupGet API
Example
Argument List
flags: <xs:unsignedInt>
userGroup: <xs:string>
userGroupModify API
Example
Argument List
newName: <xs:string>
flags: <xs:unsignedInt>
newDescription: <xs:string>
userGroup: <xs:string>
userGroupUserAddRemove API
Example
Argument List
userList: <xs:string[]>
modType: <xs:unsignedInt>
flags: <xs:unsignedInt>
userGroup: <xs:string>
userModify API
Example
Argument List
newFirstName: <xs:string>
newDefaultChapPassword: <xs:string>
newName: <xs:string>
alertSubscriptions: <xs:unsignedInt>
flags: <xs:unsignedInt>
user: <xs:string>
newDefaultChapUsername: <xs:string>
newLastName: <xs:string>
newEmailAddress: <xs:string>
newDescription: <xs:string>
newRole: <xs:string>
userPasswordSet API
Example
Argument List
newPassword: <xs:string>
oldPassword: <xs:string>
flags: <xs:unsignedInt>
user: <xs:string>
userRemove API
Example
Argument List
flags: <xs:unsignedInt>
user: <xs:string>
virtualInterfaceAssocEnum API
Example
Argument List
flags: <xs:unsignedInt>
virtualInterfaceAssocGet API
Example
Argument List
targetPortId: <xs:string>
flags: <xs:unsignedInt>
virtualInterfaceId: <xs:string>